@@ -2,6 +2,8 @@ WrRGrid<-function(ncores){
 sink(paste(getwd(),"/RGrid.R",sep=""))
 cat(paste("task.id <-",'Sys.getenv("SGE_TASK_ID")'))
 cat("\r\n")
+cat(paste("job.id <-",'Sys.getenv("JOB_ID")'))
+cat("\r\n")
 cat(paste("load(paste(getwd(),",'"/tempMPI"',',sep=""))',sep=""))
 cat("\r\n")
 #cat("set.seed(task.id)")
@@ -22,7 +24,9 @@ boundaries=boundaries,nprocs=ncores,rngoffset=dataIn$nshuffle))")
 cat("\r\n")
 cat("}")
 cat("\r\n")
-cat(paste(paste("save(x,file=paste(getwd(),",'"/mygather.temp."',",as.character(task.id)",sep=""),',sep=""))',sep=""))
+cat(paste(paste("save(x,file=paste(getwd(),",'"/mygather.temp."',",as.character(job.id)",",as.character(task.id)",sep=""),',sep=""))',sep=""))
+cat("\r\n")
+cat(paste("save(job.id,file=paste(getwd(),",'"/jobid"',',sep=""))',sep=""))
 cat("\r\n")
 sink()
 }
